"use client";
import React from "react";
import PropTypes from "prop-types";
import Card from "@components/base/card";
import Pagination from "@components/top-level/pagination";
import { useRouter, useSearchParams } from "next/navigation";
import styles from "./styles.module.css";

const BlogLists = ({
  title,
  description,
  blogs,
  currentPage,
  totalBlogLength,
}) => {
  const router = useRouter();
  const searchParams = useSearchParams();

  const redirect = (pageNumber) => {
    const searchQuery = searchParams.get("search")
      ? `&search=${searchParams.get("search")}`
      : "";
    const newUrl = `?page=${pageNumber}${searchQuery}`;
    return router.push(newUrl, undefined, { shallow: true });
  };

  const handlePageChange = (pageNumber) => {
    redirect(pageNumber);
    window.scrollTo({ top: 0, behavior: "smooth" });
  };

  return (
    <div className={styles["blog-container"]}>
      <h2 className={styles.title}>{title}</h2>
      <p className={styles.description}>{description}</p>
      <div className={styles.row}>
        {blogs.map((blogData, i) => (
          <div key={i} className={styles.col}>
            <Card {...blogData} />
          </div>
        ))}
      </div>
      <div className={styles.pagination}>
        <Pagination
          currentPage={Number(currentPage)}
          total={Number(totalBlogLength)}
          perPage={6}
          onPageChange={handlePageChange}
        />
      </div>
    </div>
  );
};

BlogLists.propTypes = {
  title: PropTypes.string,
  description: PropTypes.string,
  blogs: PropTypes.array,
  currentPage: PropTypes.number,
  totalBlogLength: PropTypes.number,
};

export default BlogLists;
